/*
 * ar4c-dcdc - pins-avr.c
 *
 * DC/DC pins configuration
 *
 * Copyright (C) 2014  Krzysztof Mazur <krzysiek@podlesie.net>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#include <avr/io.h>
#include <ltypes.h>
#include <pins.h>
#include <leds.h>

void pins_init(void)
{
	/* do not disable pull-ups */
	SFIOR &= ~BIT(PUD);

	/*
	 * port B configuration
	 *
	 * +----+----+-----+------+------+-----+-----+-------+
	 * | NC | NC | SCK | MISO | MOSI |  SS | IRQ | NC/SS |
	 * +----+----+-----+------+------+-----+-----+-------+
	 */
	DDRB = SPI_MISO | SPI_IRQ;
	PORTB = (u8) ~(SPI_MISO | SPI_MOSI | SPI_SCK | SPI_SS | SPI_IRQ);

	/*
	 * port C configuration
	 *
	 * +----+----+----+----+-----+------+------+-------+
	 * | NC | NC | NC | NC | LED | POFF | V_IN | V_BAT |
	 * +----+----+----+----+-----+------+------+-------+
	 */
	PORTC = POFF;
	DDRC = POWER_LED | POFF;
	PORTC = (u8) ~(POWER_LED | PIN_VIN | PIN_VBAT);
	
	/*
	 * port D configuration
	 *
	 * +-----------+----+----+----+----+----+----+----+
	 * | LADOWANIE | NC | NC | NC | NC | NC | NC | NC |
	 * +-----------+----+----+----+----+----+----+----+
	 */
	PORTD = 0;
	DDRD = LADOWANIE;
	PORTD = (u8) ~LADOWANIE;

	/* Disable Analog Comparator to save power */
	ACSR &= BIT(ACIE);
	ACSR |= BIT(ACD);
}
